@@ -130,6 +130,27 @@ lst2
 # join list-elements (back) into single matrix
 lrbind(lst2)
 
+## ----mergeMatrixList, echo=TRUE-----------------------------------------------
+mat1 <- matrix(11:18, ncol=2, dimnames=list(letters[3:6],LETTERS[1:2]))
+mat2 <- matrix(21:28, ncol=2, dimnames=list(letters[2:5],LETTERS[3:4]))
+mat3 <- matrix(31:38, ncol=2, dimnames=list(letters[c(1,3:4,3)],LETTERS[4:5]))
+#
+mergeMatrixList(list(mat1, mat2), useColumn="all")
+
+# with custom names for the individual matrices
+mergeMatrixList(list(m1=mat1, m2=mat2, mat3), mode="union", useColumn=2)
+
+## ----mergeMatrices, echo=TRUE-------------------------------------------------
+mergeMatrices(mat1, mat2)
+
+mergeMatrices(mat1, mat2, mat3, mode="union", useColumn=2)
+
+## custom names for matrix-origin
+mergeMatrices(m1=mat1, m2=mat2, mat3, mode="union", useColumn=2)
+
+## flexible/custom selection of columns
+mergeMatrices(m1=mat1, m2=mat2, mat3, mode="union", useColumn=list(1,1:2,2))
+
 ## ----fuseCommonListElem, echo=TRUE--------------------------------------------
 val1 <- 10 +1:26
 names(val1) <- letters
@@ -226,15 +247,14 @@ nonAmbiguousNum(aa)
 nonAmbiguousNum(aa, uniq=FALSE, asLi=TRUE)    # separate in list unique and repeated 
 
 ## ----sortByNRepeated, echo=TRUE-----------------------------------------------
-cities <- c("Bangkok","London","Paris","Singapore","New York City","Istambul","Delhi","Rome","Dubai")
-sortByNRepeated(x=cities[c(1:4)], y=cities[c(3,5:8)])
+cities <- c("Bangkok","London","Paris", "Singapore","New York City", "Istambul","Delhi","Rome","Dubai")
+sortByNRepeated(x=cities[c(1:4)], y=cities[c(2:3,5:8)])
 
 ## or (unlimited) multiple inputs via list
-choices1 <- list(Mary=cities[c(1:4)], Olivia=cities[c(3,5:8)], Paul=cities[c(5:3,9,5)])
-## Note : Paul cited NYC twice !
+choices1 <- list(Mary=cities[c(1:4)], Olivia=cities[c(2:3,5:8)], Paul=cities[c(5:3,9,5)])    # Note : Paul cited NYC twice !
 table(unlist(choices1))
 sortByNRepeated(choices1)
-sortByNRepeated(choices1, filterIntraRep=FALSE)  # without correcting multiple citation by Paul
+sortByNRepeated(choices1, filterIntraRep=FALSE)  # without correcting multiple citation of NYC by Paul
 
 ## ----cbindNR, echo=TRUE-------------------------------------------------------
 ## First we'll make soe toy data :
@@ -523,6 +543,26 @@ unifyEnumerator(c("ab-1","ab-2","c-3"))
 unifyEnumerator(c("ab-R1","ab-R2","c-R3"))
 unifyEnumerator(c("ab-1","c3-2","dR3"), stringentMatch=FALSE)
 
+## ----orderMatrToRef1, echo=TRUE-----------------------------------------------
+mat1 <- matrix(paste0("__",letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], rep(1:5)), ncol=3)
+orderMatrToRef(mat1, paste0(letters[c(3,4,5,3,4)],c(1,3,5,2,4)))
+
+mat2 <- matrix(paste0("__",letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], c(rep(1:5,2),1,1,3:5 )), ncol=3)
+orderMatrToRef(mat2, paste0(letters[c(3,4,5,3,4)],c(1,3,5,1,4)))
+
+mat3 <- matrix(paste0(letters[rep(c(1,1,2,2,3),3) +rep(0:2,each=5)], c(rep(1:5,2),1,1,3,3,5 )), ncol=3)
+orderMatrToRef(mat3, paste0("__",letters[c(3,4,5,3,4)],c(1,3,5,1,3)))
+
+## ----checkStrictOrder1, echo=TRUE---------------------------------------------
+set.seed(2005); mat1 <- rbind(matrix(round(runif(40),1),nc=4), rep(1,4))
+head(mat1)
+checkStrictOrder(mat1); mat1[which(checkStrictOrder(mat1)[,2]==0),]
+
+## ----checkGrpOrder1, echo=TRUE------------------------------------------------
+head(mat1)
+checkGrpOrder(mat1)
+checkGrpOrder(mat1, revRank=FALSE)    # only constant 'up' tested
+
 ## ----linModelSelect1, echo=TRUE-----------------------------------------------
 li1 <- rep(c(4,3,3:6), each=3) + round(runif(18)/5,2)
 names(li1) <- paste0(rep(letters[1:5], each=3), rep(1:3,6))
@@ -604,6 +644,8 @@ str(datAll)
 ## An example url with tabulated data :
 url1 <- "https://github.com/bigbio/proteomics-metadata-standard/blob/master/annotated-projects/PXD001819/PXD001819.sdrf.tsv"
 gitDataUrl(url1)
+
+## ----readGit2, echo=TRUE------------------------------------------------------
 dataPxd <- try(read.delim(gitDataUrl(url1), sep='\t', header=TRUE))
 str(dataPxd)
 
@@ -657,19 +699,23 @@ boxplot(no2, main="trimMean normalization", las=1)
 boxplot(no3, main="median normalization", las=1)
 boxplot(no4, main="slope normalization", las=1)
 
-## ----rowNormalize1, echo=FALSE, eval=TRUE-------------------------------------
+## ----rowNormalize1, echo=TRUE-------------------------------------------------
 set.seed(2); AA <- matrix(rbinom(110, 10, 0.05), nrow=10)
 AA[,4:5] <- AA[,4:5] *rep(4:3, each=nrow(AA))
 
-(AA1 <- rowNormalize(AA))
+AA1 <- rowNormalize(AA)
+round(AA1, 2)
 
-## ----rowNormalize2, echo=FALSE, eval=TRUE-------------------------------------
+## ----rowNormalize2, echo=TRUE-------------------------------------------------
 AC <- AA
 AC[which(AC <1)] <- NA
+
 (AC1 <- rowNormalize(AC))
+
+## ----rowNormalize3, echo=TRUE-------------------------------------------------
 (AC3 <- rowNormalize(AC, refLines=1:5, omitNonAlignable=TRUE))
 
-## ----coordOfFilt1, echo=FALSE, eval=TRUE--------------------------------------
+## ----coordOfFilt1, echo=TRUE--------------------------------------------------
 set.seed(2021); ma1 <- matrix(sample.int(n=40, size=27, replace=TRUE), ncol=9)
 ## let's test which values are >37
 which(ma1 >37)      # doesn't tell which row & col
@@ -745,6 +791,20 @@ matchSampToPairw(unique(grp), colnames(test8$FDR))
 mat1 <- matrix(1:8, nrow=2, dimnames=list(NULL, paste0(1:4,"-",6:9)))
 numPairDeColNames(mat1)
 
+## ----replicateStructure1, echo=TRUE-------------------------------------------
+## column a is all different, b is groups of 2,
+## c & d  are groups of 2 nut NOT 'same general' pattern as b
+strX <- data.frame(a=letters[18:11], b=letters[rep(c(3:1,4), each=2)],
+ c=letters[rep(c(5,8:6), each=2)], d=letters[c(1:2,1:3,3:4,4)],
+ e=letters[rep(c(4,8,4,7),each=2)], f=rep("z",8) )
+strX
+
+replicateStructure(strX[,1:2])
+replicateStructure(strX[,1:4], method="combAll")
+replicateStructure(strX[,1:4], method="combAll", exclNoRepl=FALSE)
+replicateStructure(strX[,1:4], method="combNonOrth", exclNoRepl=TRUE)
+replicateStructure(strX, method="lowest")
+
 ## ----std1, echo=TRUE----------------------------------------------------------
 dat <- matrix(2*round(runif(100),2), ncol=4)
 mean(dat); sd(dat)
